Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(209)

Unified Diff: components/html_viewer/web_cookie_jar_impl.cc

Issue 1157843002: Update mojo sdk to rev 1dc8a9a5db73d3718d99917fadf31f5fb2ebad4f (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/html_viewer/web_cookie_jar_impl.cc
diff --git a/components/html_viewer/web_cookie_jar_impl.cc b/components/html_viewer/web_cookie_jar_impl.cc
index 019acfb089fe50a4e46e9e18b1b5c96fc45e8170..c59bfd2a75473426457d6c543f094d0a57342f38 100644
--- a/components/html_viewer/web_cookie_jar_impl.cc
+++ b/components/html_viewer/web_cookie_jar_impl.cc
@@ -43,7 +43,7 @@ void WebCookieJarImpl::setCookie(const blink::WebURL& url,
// and URLLoader, so that we could let this method call run asynchronously
// without suffering an ordering problem. See crbug/386825.
//
- store_.WaitForIncomingMethodCall();
+ store_.WaitForIncomingResponse();
}
blink::WebString WebCookieJarImpl::cookies(
@@ -53,9 +53,9 @@ blink::WebString WebCookieJarImpl::cookies(
store_->Get(url.string().utf8(), base::Bind(&CopyString, &result));
// Wait for the result. Since every outbound request we make to the cookie
// store is followed up with WaitForIncomingMethodCall, we can be sure that
// the next incoming method call will be the response to our request.
- store_.WaitForIncomingMethodCall();
+ store_.WaitForIncomingResponse();
if (!result)
return blink::WebString();
« no previous file with comments | « components/html_viewer/web_clipboard_impl.cc ('k') | components/resource_provider/public/cpp/resource_loader.cc » ('j') | no next file with comments »
@@ -53,9 +53,9 @@ blink::WebString WebCookieJarImpl::cookies(
store_->Get(url.string().utf8(), base::Bind(&CopyString, &result));
// Wait for the result. Since every outbound request we make to the cookie
- // store is followed up with WaitForIncomingMethodCall, we can be sure that
+ // store is followed up with WaitForIncomingResponse, we can be sure that
// the next incoming method call will be the response to our request.

Powered by Google App Engine
This is Rietveld 408576698